@@ -1,8 +1,9 @@
 from bs4 import BeautifulSoup
-from souper import souper
+from ctft.souper import souper
 import html2text
 import re
 
+
 # url = "https://github.com/enedil/ctf/tree/master/2020/PoseidonCTF/mixer"
 def formatter(soup):
     
