@@ -1,7 +1,7 @@
 from bs4 import BeautifulSoup
-from souper import souper
+from ctft.souper import souper
 import html2text
-from formatter import formatter
+from ctft.formatter import formatter
 import asyncio
 
 async def github_scraper(url):
